pub struct Mutexed<M>(pub Arc<Mutex<M>>);Tuple Fields
0: Arc<Mutex<M>>Trait Implementations
Sourceimpl<M: Replaceable> Machine for Mutexed<M>
impl<M: Replaceable> Machine for Mutexed<M>
Sourcetype Seed = <M as Machine>::Seed
type Seed = <M as Machine>::Seed
Seed is piece of data that is needed to initialize the machine Read more
Sourcefn create(
seed: Self::Seed,
scope: &mut Scope<'_, M::Context>,
) -> Response<Self, Void>
fn create( seed: Self::Seed, scope: &mut Scope<'_, M::Context>, ) -> Response<Self, Void>
Create a machine from some data Read more
Sourcefn ready(
self,
events: EventSet,
scope: &mut Scope<'_, M::Context>,
) -> Response<Self, Self::Seed>
fn ready( self, events: EventSet, scope: &mut Scope<'_, M::Context>, ) -> Response<Self, Self::Seed>
Socket readiness notification
Sourcefn spawned(
self,
scope: &mut Scope<'_, M::Context>,
) -> Response<Self, Self::Seed>
fn spawned( self, scope: &mut Scope<'_, M::Context>, ) -> Response<Self, Self::Seed>
Called after spawn event Read more
Sourcefn timeout(
self,
scope: &mut Scope<'_, M::Context>,
) -> Response<Self, Self::Seed>
fn timeout( self, scope: &mut Scope<'_, M::Context>, ) -> Response<Self, Self::Seed>
Timeout happened
Sourcefn wakeup(self, scope: &mut Scope<'_, M::Context>) -> Response<Self, Self::Seed>
fn wakeup(self, scope: &mut Scope<'_, M::Context>) -> Response<Self, Self::Seed>
Message received Read more
Sourcefn spawn_error(
self,
_scope: &mut Scope<'_, Self::Context>,
error: SpawnError<Self::Seed>,
) -> Response<Self, Self::Seed>
fn spawn_error( self, _scope: &mut Scope<'_, Self::Context>, error: SpawnError<Self::Seed>, ) -> Response<Self, Self::Seed>
Called instead of spawned, if there is no slab space Read more