pub struct Ticker<M: Timer> { /* private fields */ }Expand description
Ticker state machine
The structure implements rotor::Machine but exposes a simpler protocol
that has just one method which is called when timer expires.
The Ticker machine also ensures that there are no spurious events.
Implementations